==> orangehrm-2.4.0.1.tar.gz: orangehrm-2.4.0.1/lib/extractor/hrfunct/EXTRACTOR_EmpConExt.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

require_once ROOT_PATH . '/lib/models/hrfunct/EmpConExt.php';

class EXTRACTOR_EmpConExt {

	function EXTRACTOR_EmpConExt() {
		$this->empconext= new EmpConExt();
	}

	function parseData($postArr) {

		$postArr['txtEmpConExtStartDat']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpConExtStartDat']);
		$postArr['txtEmpConExtEndDat']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpConExtEndDat']);

		$this->empconext->setEmpId(trim($postArr['txtEmpID']));
  		$this->empconext->setEmpConExtId(trim($postArr['txtEmpConExtID']));
   		$this->empconext->setEmpConExtStartDat(trim($postArr['txtEmpConExtStartDat']));
  		$this->empconext->setEmpConExtEndDat(trim($postArr['txtEmpConExtEndDat']));

		return $this->empconext;
	}
}
?>

==> orangehrm-2.5.0.4.tar.gz: orangehrm-2.5.0.4/lib/extractor/hrfunct/EXTRACTOR_EmpConExt.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

require_once ROOT_PATH . '/lib/models/hrfunct/EmpConExt.php';

class EXTRACTOR_EmpConExt {

	public function __construct() {
		$this->empconext= new EmpConExt();
	}

	public function parseData($postArr) {

		$postArr['txtEmpConExtStartDat']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpConExtStartDat']);
		$postArr['txtEmpConExtEndDat']=LocaleUtil::getInstance()->convertToStandardDateFormat($postArr['txtEmpConExtEndDat']);

		$this->empconext->setEmpId(trim($postArr['txtEmpID']));
  		$this->empconext->setEmpConExtId(trim($postArr['txtEmpConExtID']));
   		$this->empconext->setEmpConExtStartDat(self::_handleEmptyDates(trim($postArr['txtEmpConExtStartDat'])));
  		$this->empconext->setEmpConExtEndDat(self::_handleEmptyDates(trim($postArr['txtEmpConExtEndDat'])));

		return $this->empconext;
	}
	
	private static function _handleEmptyDates($date) {

		$date = trim($date);

	    if ($date == "" || $date == "YYYY-mm-DD" || $date == "0000-00-00") {
			return "null";
	    } else {
	        return "'".$date."'";
	    }

	}
	
}
?>
